==> haskell-aeson-diff-1.1.0.13-259-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-diff
version:              1.1.0.13
visibility:           public
id:                   aeson-diff-1.1.0.13-6JCVniPrQebHkpEff1XtG3
key:                  aeson-diff-1.1.0.13-6JCVniPrQebHkpEff1XtG3
license:              BSD-3-Clause
copyright:            (c) 2015 Thomas Sutton and others.
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Thomas Sutton
homepage:             https://github.com/ysangkok/aeson-diff
synopsis:             Extract and apply patches to JSON documents.
description:

    This is a small library for working with changes to JSON documents. It
    includes a library and two command-line executables in the style of the
    diff(1) and patch(1) commands available on many systems.

category:             JSON, Web, Algorithms
abi:                  046332056c0b4ff9f608ee0df59bf525
exposed:              True
exposed-modules:      Data.Aeson.Diff Data.Aeson.Patch Data.Aeson.Pointer
import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-diff-1.1.0.13
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-diff-1.1.0.13
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-diff-1.1.0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-diff
hs-libraries:         HSaeson-diff-1.1.0.13-6JCVniPrQebHkpEff1XtG3
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    bytestring-0.11.5.3
    edit-distance-vector-1.0.0.4-F1grvBoSdSQ50bLZkbeVql
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW text-2.0.2
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-aeson-diff/html/aeson-diff.haddock
haddock-html:         /usr/share/doc/haskell-aeson-diff/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-diff-1.1.0.13-262-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-diff
version:              1.1.0.13
visibility:           public
id:                   aeson-diff-1.1.0.13-30223XcxamACGHhADdpFax
key:                  aeson-diff-1.1.0.13-30223XcxamACGHhADdpFax
license:              BSD-3-Clause
copyright:            (c) 2015 Thomas Sutton and others.
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Thomas Sutton
homepage:             https://github.com/ysangkok/aeson-diff
synopsis:             Extract and apply patches to JSON documents.
description:

    This is a small library for working with changes to JSON documents. It
    includes a library and two command-line executables in the style of the
    diff(1) and patch(1) commands available on many systems.

category:             JSON, Web, Algorithms
abi:                  84187234c97155ff0bd53c4e0b1c4eed
exposed:              True
exposed-modules:      Data.Aeson.Diff Data.Aeson.Patch Data.Aeson.Pointer
import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-diff-1.1.0.13
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-diff-1.1.0.13
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-diff-1.1.0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-diff
hs-libraries:         HSaeson-diff-1.1.0.13-30223XcxamACGHhADdpFax
depends:
    aeson-2.2.0.0-Hqy1Zqe0ZE81dk2L20icmH base-4.18.2.1
    bytestring-0.11.5.3
    edit-distance-vector-1.0.0.4-1tn6821b1d63Kly1WwaLgw
    scientific-0.3.8.0-E8K90IhCZpR98POp8HwlML text-2.0.2
    vector-0.13.2.0-DULMVARQ1CU3TLBOg9xkS6

haddock-interfaces:   /usr/share/doc/haskell-aeson-diff/html/aeson-diff.haddock
haddock-html:         /usr/share/doc/haskell-aeson-diff/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
